@@ -154,6 +154,8 @@ class Invert(ImageFilter):
     to 255). Therefore, inverting its values could ease the removal of non-tissue
     regions (values close or equal to 0).
 
+    .. figure:: https://user-images.githubusercontent.com/31658006/116548383-6aaad800-a8f4-11eb-8ebd-46c873046447.png
+
     Parameters
     ----------
     img : PIL.Image.Image
@@ -327,7 +329,6 @@ class EosinChannel(ImageFilter):
     Example:
         >>> from PIL import Image
         >>> from histolab.filters.image_filters import EosinChannel
-        >>> from histolab.filters import image_filters_functional as imf
         >>> image_rgb = Image.open("tests/fixtures/pil-images-rgb/tcga-lung-rgb.png")
         >>> eosin_channel = EosinChannel()
         >>> image_e = eosin_channel(image_rgb)
@@ -338,6 +339,36 @@ class EosinChannel(ImageFilter):
         return eosin
 
 
+class DABChannel(ImageFilter):
+    """Obtain DAB channel from RGB image.
+
+    Input image is first converted into HED space and the DAB channel is
+    rescaled for increased contrast.
+
+    Parameters
+    ----------
+    img : Image.Image
+        Input RGB image
+
+    Returns
+    -------
+    Image.Image
+        Grayscale image corresponding to input image with DAB channel enhanced.
+
+
+    Example:
+        >>> from PIL import Image
+        >>> from histolab.filters.image_filters import DABChannel
+        >>> image_rgb = Image.open("tests/fixtures/pil-images-rgb/tcga-lung-rgb.png")
+        >>> dab_channel = DABChannel()
+        >>> image_d = dab_channel(image_rgb)
+    """  # noqa
+
+    def __call__(self, img):
+        dab = F.dab_channel(img)
+        return dab
+
+
 class RgbToHsv(ImageFilter):
     """Convert RGB channels to HSV channels.
 
@@ -384,6 +415,8 @@ class StretchContrast(ImageFilter):
     :math:`v_{o,l}=40` and :math:`v_{o,l}=60` as default values.
     This filter is useful to highlight details in the input image.
 
+    .. figure:: https://user-images.githubusercontent.com/31658006/116539805-9f656200-a8e9-11eb-913b-864c0a9d8baf.png
+
     Parameters
     ----------
     img: PIL.Image.Image
@@ -442,6 +475,8 @@ class HistogramEqualization(ImageFilter):
     equalization, as it works uniformly on the whole image and the transformation of one
     pixel is independent from the transformation used on the neighboring pixels [4]_.
 
+    .. figure:: https://user-images.githubusercontent.com/31658006/116540462-76919c80-a8ea-11eb-86f0-0b0d318292e3.png
+
     Notice that the histogram equalization method can be used for RGB images
     by applying the same algorithm on the R, G, and B channels separately [5]_;
     nonetheless, the high correlation of the three channels may distort the image and
@@ -495,6 +530,8 @@ class AdaptiveEqualization(ImageFilter):
     lighter regions that may be poorly enhanced by the global histogram equalization
     transformation.
 
+    .. figure:: https://user-images.githubusercontent.com/31658006/116540919-13ecd080-a8eb-11eb-99ef-c879f80fe542.png
+
     The Adaptive Equalization filter is based on the scikit-image implementation of
     the contrast limited adaptive histogram equalization (CLAHE) [1]_.
 
@@ -578,6 +615,8 @@ class KmeansSegmentation(ImageFilter):
     By using K-means segmentation (color/space proximity) each segment is colored based
     on the average color for that segment.
 
+    .. figure:: https://user-images.githubusercontent.com/31658006/116543486-37fde100-a8ee-11eb-8695-75fae5767de1.jpeg
+
     Parameters
     ---------
     img : PIL.Image.Image
@@ -620,6 +659,8 @@ class RagThreshold(ImageFilter):
     the segments, combine similar regions based on threshold value,
     and then output these resulting region segments.
 
+    .. figure:: https://user-images.githubusercontent.com/31658006/116553449-6a154000-a8fa-11eb-8e74-b9d711e79113.jpeg
+
     Parameters
     ----------
     img : PIL.Image.Image
@@ -668,6 +709,8 @@ class HysteresisThreshold(ImageFilter):
     kept only if connected to a strong one. The hysteresis thresholding can be applied
     to detect edges in an image.
 
+    .. figure:: https://user-images.githubusercontent.com/31658006/116542328-d5f0ac00-a8ec-11eb-9f05-696ca0598fd4.png
+
     Parameters
     ----------
     img : PIL.Image.Image
@@ -795,6 +838,8 @@ class OtsuThreshold(ImageFilter):
 
     Note that Otsu threshold is expected to work correctly only for grayscale images.
 
+    .. figure:: https://user-images.githubusercontent.com/31658006/116542034-76929c00-a8ec-11eb-98ca-9e0d283cdcbb.png
+
     Parameters
     ----------
     img : PIL.Image.Image
@@ -840,6 +885,8 @@ class FilterEntropy(ImageFilter):
 
     Note that input must be 2D.
 
+    .. figure:: https://user-images.githubusercontent.com/31658006/116543013-a1312480-a8ed-11eb-8f75-b25164286994.png
+
     Parameters
     ----------
     img : PIL.Image.Image
@@ -888,6 +935,8 @@ class CannyEdges(ImageFilter):
 
     Note that input image must be 2D.
 
+    .. figure:: https://user-images.githubusercontent.com/31658006/116542613-1d773800-a8ed-11eb-9005-4c0ad8d051b8.png
+
     Parameters
     ----------
     img : PIL.Image.Image
@@ -984,6 +1033,8 @@ class GreenChannelFilter(ImageFilter):
 
     This method alone may be sufficient to segment tissue on H&E-stained images.
 
+    .. figure:: https://user-images.githubusercontent.com/31658006/116541610-f53b0980-a8eb-11eb-939d-944ebc7c87ee.png
+
     Parameters
     ----------
     img : PIL.Image.Image
@@ -1146,6 +1197,8 @@ class GreenPenFilter(ImageFilter):
     The resulting mask is a composition of green filters with different thresholds
     for the RGB channels.
 
+    .. figure:: https://user-images.githubusercontent.com/31658006/116548722-f290e200-a8f4-11eb-9780-0ce5844295dd.png
+
     Parameters
     ---------
     img : PIL.Image.Image
@@ -1259,6 +1312,8 @@ class YenThreshold(ImageFilter):
     gray level (s-1). In this filter, pixels below the computed threshold are
     considered as foreground.
 
+    .. figure:: https://user-images.githubusercontent.com/31658006/116542194-ab065800-a8ec-11eb-9fea-24dd97de8226.png
+
     Parameters
     ----------
     img : PIL.Image.Image
