@@ -44,7 +44,7 @@ class Slide:
     path : Union[str, pathlib.Path]
         Path where the WSI is saved.
     processed_path : Union[str, pathlib.Path]
-        Path where thumbnails and scaled images will be saved to.
+        Path where the tiles will be saved to.
     """
 
     def __init__(
@@ -66,7 +66,7 @@ class Slide:
 
     @lazyproperty
     def dimensions(self) -> Tuple[int, int]:
-        """Return the slide dimensions (w,h) at level 0.
+        """Slide dimensions (w,h) at level 0.
 
         Returns
         -------
@@ -134,7 +134,7 @@ class Slide:
 
     @lazyproperty
     def levels(self) -> List[int]:
-        """Return the slide's available levels
+        """Slide's available levels
 
         Returns
         -------
@@ -200,22 +200,23 @@ class Slide:
 
     @lazyproperty
     def name(self) -> str:
-        """Retrieve the slide name without extension.
+        """Slide name without extension.
 
         Returns
         -------
         name : str
         """
-        return ntpath.basename(self._path).split(".")[0]
+        bname = ntpath.basename(self._path)
+        return bname[: bname.rfind(".")]
 
     @lazyproperty
     def processed_path(self) -> str:
-        """Retrieve the path to store processed files generated from the slide.
+        """Path to store the tiles generated from the slide.
 
         Returns
         -------
         str
-            Path to store processed files generated from the slide
+            Path to store the tiles generated from the slide
         """
         return self._processed_path
 
@@ -231,7 +232,7 @@ class Slide:
         return dict(self._wsi.properties)
 
     def resampled_array(self, scale_factor: int = 32) -> np.array:
-        """Retrieve the resampled array from the original slide
+        """Return the resampled array from the original slide
 
         Parameters
         ----------
@@ -273,7 +274,7 @@ class Slide:
 
     @lazyproperty
     def thumbnail(self) -> PIL.Image.Image:
-        """Return the slide thumbnail.
+        """Slide thumbnail.
 
         Returns
         -------
@@ -526,7 +527,7 @@ class SlideSet:
 
     @lazyproperty
     def slides_stats(self) -> dict:
-        """Compute statistics for the WSI collection, namely the number of available
+        """Statistics for the WSI collection, namely the number of available
         slides; the slide with the maximum/minimum width; the slide with the
         maximum/minimum height; the slide with the maximum/minimum size; the average
         width/height/size of the slides.
