@@ -6,12 +6,24 @@ import os
 import sys
 
 import numpy as np
-import PIL
+import pytest
+from PIL import Image
+
+from histolab import data
+from histolab.slide import Slide
 
 from unittest.mock import ANY, call  # noqa # isort:skip
 from unittest.mock import create_autospec, patch, PropertyMock  # isort:skip
 
 
+def base_test_slide(tmpdir, image):
+    tmp_path_ = tmpdir.mkdir("myslide")
+    image.save(os.path.join(tmp_path_, "mywsi.png"), "PNG")
+    slide_path = os.path.join(tmp_path_, "mywsi.png")
+    slide = Slide(slide_path, "processed")
+    return slide, tmp_path_
+
+
 def dict_list_eq(l1, l2):
     sorted_l1 = sorted(sorted(d.items()) for d in l1)
     sorted_l2 = sorted(sorted(d.items()) for d in l2)
@@ -84,6 +96,14 @@ def property_mock(request, cls, prop_name, **kwargs):
     return _patch.start()
 
 
+def fetch(data_filename):
+    """Attempt to fetch data, but if unavailable, skip the tests."""
+    try:
+        return data._fetch(data_filename)
+    except (ConnectionError, ModuleNotFoundError):
+        pytest.skip(f"Unable to download {data_filename}")
+
+
 def on_ci():
     # GitHub Actions, Travis and AppVeyor have "CI"
     return "CI" in os.environ
@@ -94,24 +114,23 @@ def is_win32():
 
 
 class PILImageMock:
-    DIMS_500X500_RGBA_COLOR_155_249_240 = PIL.Image.new(
+    RGBA_COLOR_500X500_155_249_240 = Image.new(
         "RGBA", size=(500, 500), color=(155, 249, 240)
     )
-    DIMS_50X50_RGBA_COLOR_155_0_0 = PIL.Image.new(
-        "RGBA", size=(50, 50), color=(155, 0, 0)
-    )
 
-    DIMS_500X500_RGB_RANDOM_COLOR = PIL.Image.fromarray(
+    RGBA_COLOR_50X50_155_0_0 = Image.new("RGBA", size=(50, 50), color=(155, 0, 0))
+
+    RGBA_COLOR_49X51_155_0_0 = Image.new("RGBA", size=(49, 51), color=(155, 0, 0))
+
+    RGB_RANDOM_COLOR_500X500 = Image.fromarray(
         (np.random.rand(500, 500, 3) * 255).astype("uint8")
     ).convert("RGB")
 
-    DIMS_10X10_RGB_RANDOM_COLOR = PIL.Image.fromarray(
+    RGB_RANDOM_COLOR_10X10 = Image.fromarray(
         (np.random.rand(10, 10, 3) * 255).astype("uint8")
     ).convert("RGB")
 
-    DIMS_10X10_GRAY_RANDOM = PIL.Image.fromarray(
-        (np.random.rand(10, 10) * 255).astype("uint8")
-    )
+    GRAY_RANDOM_10X10 = Image.fromarray((np.random.rand(10, 10) * 255).astype("uint8"))
 
 
 class NpArrayMock:
@@ -119,3 +138,6 @@ class NpArrayMock:
     ONES_500X500X4_BOOL = np.ones([500, 500, 4], dtype="bool")
     ONES_500X500_BOOL = np.ones([500, 500], dtype="bool")
     RANDOM_500X500_BOOL = np.random.rand(500, 500) > 0.5
+
+
+PILIMG = PILImageMock
